import{p as e,f as o}from"./flowDb-956e92f1-b6f105ac.js";import{f as t,g as a}from"./styles-c10674c1-f86aab11.js";import{u as i}from"./index-098a1a24.js";import"./graph-6e2ab9a7.js";import"./layout-d98dcd0c.js";import"./index-3862675e-84ec700f.js";import"./clone-ff7f2ce7.js";import"./edges-e0da2a9e-77e89e48.js";import"./createText-2e5e7dd3-9c105cb1.js";import"./line-838e3d82.js";import"./array-9f3ba611.js";import"./path-53f90ab3.js";import"./channel-11268142.js";const M={parser:e,db:o,renderer:t,styles:a,init:r=>{r.flowchart||(r.flowchart={}),r.flowchart.arrowMarkerAbsolute=r.arrowMarkerAbsolute,i({flowchart:{arrowMarkerAbsolute:r.arrowMarkerAbsolute}}),t.setConf(r.flowchart),o.clear(),o.setGen("gen-2")}};export{M as diagram};
